@@ -1,15 +1,15 @@
 import io
 from distutils import dist
-from typing import Mapping
+from typing import Mapping, Optional
 
 import pkg_resources
 
 
-def extract_metadata() -> Mapping[str, str]:
+def extract_metadata() -> Mapping[str, Optional[str]]:
 
     distribution = pkg_resources.get_distribution("vault-cli")
     metadata_str = distribution.get_metadata(distribution.PKG_INFO)
-    metadata_obj = dist.DistributionMetadata()  # type: ignore
+    metadata_obj = dist.DistributionMetadata()
     metadata_obj.read_pkg_file(io.StringIO(metadata_str))
 
     return {
